cgexplore.forcefields.MartiniForceField
=======================================

.. currentmodule:: cgexplore.forcefields

.. autoclass:: MartiniForceField
   :members:
   :inherited-members:
   :undoc-members:
   :show-inheritance:


   
   
   .. rubric:: Methods

   .. autosummary::
      :nosignatures:
   
      ~MartiniForceField.assign_terms
   
   

   
   
   